Module bitmap

Module bitmap 

Re-exports

pub use refs::*;

Modules

fmt
Implementations of formating methods for Bitmap, including Debug.
from
Implementations of From and Into for Bitmap, BitRef and BitRefMut.
macros
Providing macros to create bitmap convenently.
ops
Implementations of logic operations like BitAnd and BitOrAssign for Bitmap.
ptr
refs
Bit ref wrappers.

Macros

he_lang
A wrapper of newmap, which is a painted eggshell. Create a bitmap with indexes instead of flags.
newmap
Create a cbitmap::bitmap::Bitmap by specifying the bit length and flags.

Structs

Bitmap
A size-fixed bitmap with croase-granularity (byte) and conventional interfaces.

Traits

BitsManage
A general trait, structs which implemented this trait provide interfaces to access a range of bits.
FillPrefix
Fill the first several bytes (8*bits) of a bitmap.